image-resize
============

Python tool to resize a bunch of images quickly.

Installation
------------

Install via pip using:

``pip install image-resize``

Get the cutting edge version using:

``pip install -e git+https://github.com/ssundarraj/image_resizer.git#egg=image_resizer``

or

Clone/download the git repo, and install using ``python setup.py``.

Usage
-----

``image-resize input_file.jpg``
